@@ -1,48 +1,28 @@
 /*
- * Copyright IBM Corp 2007, 2010
- * Author: Hans-Joachim Picht <hans@linux.vnet.ibm.com>
+ * cpuplugd - Linux for System z Hotplug Daemon
  *
- *  Linux for System z Hotplug Daemon
+ * CPU hotplug functions
  *
- * This program is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License as published by the Free
- * Software Foundation; either version 2 of the License, or (at your option)
- * any later version.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Copyright IBM Corp 2007, 2011
+ * Author(s): Gerald Schaefer <gerald.schaefer@de.ibm.com>
+ *            Hans-Joachim Picht <hans@linux.vnet.ibm.com>
  */
 
-#include <ctype.h>
-#include <getopt.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <unistd.h>
-#include <errno.h>
-#include <string.h>
-#include <fcntl.h>
-#include <sys/stat.h>
-#include <sys/wait.h>
-#include <sys/types.h>
-#include <signal.h>
-#include <syslog.h>
-#include <pthread.h>
+#include <limits.h>
 #include "cpuplugd.h"
 
-static const int max_cpus = MAX_CPU;
 
 /*
- * return overall number of available cpus. this does not necessarily
+ * Return overall number of available cpus. This does not necessarily
  * mean that those are currently online
  */
 int get_numcpus()
 {
 	int i;
-	char path[4069];
+	char path[PATH_MAX];
 	int number = 0;
 
-	for (i = 0; i <= max_cpus; i++) {
+	for (i = 0; i <= MAX_CPU; i++) {
 		/* check whether file exists and is readable */
 		sprintf(path, "/sys/devices/system/cpu/cpu%d/online", i);
 		if (access(path, R_OK) == 0)
@@ -52,13 +32,13 @@ int get_numcpus()
 }
 
 /*
- * return number of online cpus
+ * Return number of online cpus
  */
 int get_num_online_cpus()
 {
 	FILE *filp;
 	int i;
-	char path[4069];
+	char path[PATH_MAX];
 	int status = 0;
 	int value_of_onlinefile, rc;
 
@@ -68,17 +48,14 @@ int get_num_online_cpus()
 		if (access(path, R_OK) != 0)
 			continue;
 		filp = fopen(path, "r");
-		if (!filp) {
-			cpuplugd_error("Cannot open cpu online file: "
-				       "%s\n", strerror(errno));
-			exit(1);
-		} else {
+		if (!filp)
+			cpuplugd_exit("Cannot open cpu online file: "
+				      "%s\n", strerror(errno));
+		else {
 			rc = fscanf(filp, "%d", &value_of_onlinefile);
-			if (rc != 1) {
-				cpuplugd_error("Cannot read cpu online file: "
-					       "%s\n", strerror(errno));
-				exit(1);
-			}
+			if (rc != 1)
+				cpuplugd_exit("Cannot read cpu online file: "
+					      "%s\n", strerror(errno));
 			if (value_of_onlinefile == 1)
 				status++;
 		}
@@ -88,22 +65,20 @@ int get_num_online_cpus()
 }
 
 /*
- * enable a certain cpu
+ * Enable a certain cpu
  */
 int hotplug(int cpuid)
 {
 	FILE *filp;
-	char path[4096];
+	char path[PATH_MAX];
 	int status, rc;
 
 	sprintf(path, "/sys/devices/system/cpu/cpu%d/online", cpuid);
 	if (access(path, W_OK) == 0) {
 		filp = fopen(path, "w");
-		if (!filp) {
-			cpuplugd_error("Cannot open cpu online file: %s\n",
-				       strerror(errno));
-			exit(1);
-		}
+		if (!filp)
+			cpuplugd_exit("Cannot open cpu online file: %s\n",
+				      strerror(errno));
 		fprintf(filp, "1");
 		fclose(filp);
 		/*
@@ -111,11 +86,9 @@ int hotplug(int cpuid)
 		 */
 		filp = fopen(path, "r");
 		rc = fscanf(filp, "%d", &status);
-		if (rc != 1) {
-			cpuplugd_error("Cannot open cpu online file: %s\n",
-				       strerror(errno));
-			exit(1);
-		}
+		if (rc != 1)
+			cpuplugd_exit("Cannot open cpu online file: %s\n",
+				      strerror(errno));
 		fclose(filp);
 		if (status == 1) {
 			cpuplugd_debug("cpu with id %d enabled\n", cpuid);
@@ -133,14 +106,14 @@ int hotplug(int cpuid)
 }
 
 /*
- * disable a certain cpu
+ * Disable a certain cpu
  */
 int hotunplug(int cpuid)
 {
 	FILE *filp;
 	int state, rc;
 	int retval = -1;
-	char path[4096];
+	char path[PATH_MAX];
 
 	state = -1;
 	sprintf(path, "/sys/devices/system/cpu/cpu%d/online", cpuid);
@@ -149,7 +122,7 @@ int hotunplug(int cpuid)
 		fprintf(filp, "0");
 		fclose(filp);
 		/*
-		 * check if the attempt to enable the cpus really worked
+		 * Check if the attempt to enable the cpus really worked
 		 */
 		filp = fopen(path, "r");
 		rc = fscanf(filp, "%d", &state);
@@ -166,14 +139,14 @@ int hotunplug(int cpuid)
 }
 
 /*
- * check if a certain cpu is currently online
+ * Check if a certain cpu is currently online
  */
 int is_online(int cpuid)
 {
 	FILE *filp;
 	int state;
 	int retval, rc;
-	char path[4096];
+	char path[PATH_MAX];
 
 	retval = -1;
 	sprintf(path, "/sys/devices/system/cpu/cpu%d/online", cpuid);
@@ -192,12 +165,12 @@ int is_online(int cpuid)
 }
 
 /*
- * cleanup method. if the daemon is stopped, we (re) activate all cpus
+ * Cleanup method. If the daemon is stopped, we (re)activate all cpus
  */
 void reactivate_cpus()
 {
 	/*
-	 * only enable the number of cpus which where
+	 * Only enable the number of cpus which where
 	 * available at daemon startup time
 	 */
 	int cpuid, nc;
@@ -206,8 +179,8 @@ void reactivate_cpus()
 	/* suppress verbose messages on exit */
 	debug = 0;
        /*
-	* we check for num_cpu_start != 0 because we might want to
-	* clean up, before we queried for the number on cpus  at
+	* We check for num_cpu_start != 0 because we might want to
+	* clean up, before we queried for the number on cpus at
 	* startup
 	*/
 	if (num_cpu_start == 0)
@@ -225,7 +198,7 @@ void reactivate_cpus()
 }
 
 /*
- * in system > 2.6.24 cpus can be deconfigured. the follwoing functions is used
+ * In kernels > 2.6.24 cpus can be deconfigured. The follwoing functions is used
  * to check if a certain cpus is in a deconfigured state.
  */
 int cpu_is_configured(int cpuid)
