@@ -1,33 +1,37 @@
 /*
- * Copyright IBM Corp 2007, 2010
- * Author: Hans-Joachim Picht <hans@linux.vnet.ibm.com>
+ * cpuplugd - Linux for System z Hotplug Daemon
  *
- * Linux for System z Hotplug Deamon
+ * Header file
  *
- * This program is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License as published by the Free
- * Software Foundation; either version 2 of the License, or (at your option)
- * any later version.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Copyright IBM Corp 2007, 2011
+ * Author(s): Gerald Schaefer <gerald.schaefer@de.ibm.com>
+ *            Hans-Joachim Picht <hans@linux.vnet.ibm.com>
  */
 
-#include <ctype.h>
-#include <getopt.h>
+#ifndef __USE_ISOC99
+#define __USE_ISOC99
+#endif
 #include <stdio.h>
-#include <stdlib.h>
-#include <unistd.h>
 #include <errno.h>
 #include <string.h>
-#include <fcntl.h>
-#include <sys/stat.h>
-#include <sys/wait.h>
-#include <sys/types.h>
+#include <unistd.h>
+#include <stdlib.h>
 #include <signal.h>
+#include <ctype.h>
 #include <syslog.h>
-#include <pthread.h>
+#include <setjmp.h>
+
+#define NAME		"cpuplugd"
+#define MAX_CPU		64 /* max amount of possible cpus */
+#define MAX_HISTORY	100
+#define PIDFILE		"/var/run/cpuplugd.pid"
+#define LOCKFILE	"/var/lock/cpuplugd.lock"
+#define PROCINFO_LINE	512
+#define CPUSTAT_SIZE	1024
+#define VARINFO_SIZE	4096
+#define MAX_VARNAME	128
+#define MAX_LINESIZE	2048
+#define CPUSTATS	10
 
 /*
  *  Precedence of C operators
@@ -57,10 +61,23 @@ enum operation {
 	OP_SYMBOL_LOADAVG,
 	OP_SYMBOL_RUNABLE,
 	OP_SYMBOL_CPUS,
+	OP_SYMBOL_USER,
+	OP_SYMBOL_NICE,
+	OP_SYMBOL_SYSTEM,
 	OP_SYMBOL_IDLE,
+	OP_SYMBOL_IOWAIT,
+	OP_SYMBOL_IRQ,
+	OP_SYMBOL_SOFTIRQ,
+	OP_SYMBOL_STEAL,
+	OP_SYMBOL_GUEST,
+	OP_SYMBOL_GUEST_NICE,
 	OP_SYMBOL_APCR,
 	OP_SYMBOL_SWAPRATE,
 	OP_SYMBOL_FREEMEM,
+	OP_SYMBOL_MEMINFO,
+	OP_SYMBOL_VMSTAT,
+	OP_SYMBOL_CPUSTAT,
+	OP_SYMBOL_TIME,
 	OP_CONST,
 	/* Unary operators */
 	OP_NEG,
@@ -77,24 +94,35 @@ enum operation {
 	/* ... */
 	/*Variables which are eligible within rules*/
 	VAR_LOAD,       /* loadaverage */
-	VAR_RUN,        /* number of runable processes */
+	VAR_RUN,        /* number of runnable processes */
 	VAR_ONLINE     /* number of online cpus */
 };
 
 struct symbols {
 	double loadavg;
-	double runable_proc;
+	double runnable_proc;
 	double onumcpus;
 	double idle;
 	double freemem;
 	double apcr;
 	double swaprate;
+	double user;
+	double nice;
+	double system;
+	double iowait;
+	double irq;
+	double softirq;
+	double steal;
+	double guest;
+	double guest_nice;
 };
 
 struct term {
 	enum operation op;
 	double value;
 	struct term *left, *right;
+	char *proc_name;
+	unsigned int index;
 };
 
 /*
@@ -102,113 +130,83 @@ struct term {
  *
  */
 struct config {
-	int cpu_max;
-	int cpu_min;
-	int update;
-	int cmm_max;
-	int cmm_min;
-	int cmm_inc;
-	long long idle_ticks;
+	long cpu_max;
+	long cpu_min;
+	long update;
+	long cmm_max;
+	long cmm_min;
+	struct term *cmm_inc;
+	struct term *cmm_dec;
 	struct term *hotplug;
 	struct term *hotunplug;
 	struct term *memplug;
 	struct term *memunplug;
 };
 
-struct thread1_params {
-	struct vmstat *vs;
-	pthread_mutex_t pm;
+struct symbol_names {
+	char *name;
+	enum operation symop;
 };
 
-struct vmstat {
-	int bi;		/* Blocks received from a block device (blocks/s) */
-	int bo;		/* Blocks sent to a block device (blocks/s) */
-	int si;		/* Amount of memory swapped in from disk (/s) */
-	int so;		/* Amount of memory swapped to disk (/s) */
-	int available;	/* boolean flag to check if the computed values are
-			   already available */
-};
-
-
-struct vm_info {
-	unsigned long long pgpgout;		/* page out */
-	unsigned long long pswpout;		/* page swap out */
-	unsigned long long pswpin;		/* page swap in */
-	unsigned long long pgpgin;		/* page in */
-};
-
-
-/*
- * used to query data from /proc/stat
- */
-struct cpustat  {
-	unsigned int cpu_info;
-	unsigned int cpu_user;
-	unsigned int cpu_nice;
-	unsigned int cpu_idle;
-	unsigned int cpu_iow;
-	unsigned int cpu_irq;
-	unsigned int cpu_softirq;
-	unsigned int cpu_sys;
-	unsigned int cpu_steal;
-};
-
-
-#define NAME "cpuplugd"
-#define MAX_CPU 64 /* max amount of possible cpus */
-#define PIDFILE "/var/run/cpuplugd.pid"
-#define MAXRULES 100
-#define USER_HERTZ  100
-#define VMSTAT        0
-#define SLABSTAT      0x00000004
-
 extern int foreground;
 extern int debug;
 extern char *configfile;
 extern int debug;        /* is verbose specified? */
-extern int swaprate;
-extern int apcr;	/* amount of page cache reads */
 extern int memory;
 extern int cpu;
 extern int num_cpu_start; /* # of online cpus at the time of the startup */
-extern int cmm_pagesize_start; /* cmm_pageize at the time of daemon startup */
+extern long cmm_pagesize_start; /* cmm_pageize at the time of daemon startup */
 extern struct config cfg;
-extern int sem;
+extern int reload_pending;
+extern unsigned long meminfo_size;
+extern unsigned long vmstat_size;
+extern unsigned long cpustat_size;
+extern unsigned long varinfo_size;
+extern char *meminfo;
+extern char *vmstat;
+extern char *cpustat;
+extern char *varinfo;
+extern double *timestamps;
+extern unsigned int history_max;
+extern unsigned int history_current;
+extern struct symbol_names sym_names[];
+extern unsigned int sym_names_count;
 
 int get_numcpus();
 int get_num_online_cpus();
-int get_runable_proc();
-long long get_idle_ticks();
-float get_loadavg();
+void get_loadavg_runnable(double *loadavg, double *runnable);
 void clean_up();
 void reactivate_cpus();
-void parse_configfile(struct config *cfg, char *file);
-void free_term(struct term *fn);
+void parse_configfile(char *file);
 void print_term(struct term *fn);
 struct term *parse_term(char **p, enum op_prio prio);
 int eval_term(struct term *fn, struct symbols *symbols);
-void *get_info(void *parameters);
-int cleanup_cmm();
+double eval_double(struct term *fn, struct symbols *symbols);
+double get_proc_value(char *procinfo, char *name, char separator);
+void proc_read(char *procinfo, char *path, unsigned long size);
+void proc_cpu_read(char *procinfo);
+unsigned long proc_read_size(char *path);
+char *get_var_rvalue(char *var_name);
+void cleanup_cmm(void);
 int hotplug(int cpuid);
 int hotunplug(int cpuid);
-int memplug(int size);
-int memunplug(int size);
 int is_online(int cpuid);
-int get_cmmpages_size();
+long get_cmmpages_size();
 void parse_options(int argc, char **argv);
 void check_if_started_twice();
 void store_pid(void);
 void handle_signals(void);
 void handle_sighup(void);
-int get_vmstats(struct vm_info *v);
-unsigned long unit_convert(unsigned int size);
+void reload_daemon(void);
 int check_cmmfiles(void);
-int get_free_memsize();
-void check_config(struct config *cfg);
-void check_max(struct config *cfg);
-int set_cmm_pages(int size);
+void check_config();
+void set_cmm_pages(long size);
 int check_lpar();
 int cpu_is_configured(int cpuid);
+void setup_history(void);
+
+#define MIN(a, b) ((a) < (b) ? (a) : (b))
+#define MAX(a, b) ((a) < (b) ? (b) : (a))
 
 #define cpuplugd_info(fmt, ...) ({			\
 	if (foreground == 1)				\
@@ -229,3 +227,7 @@ int cpu_is_configured(int cpuid);
 		cpuplugd_info(fmt, ##__VA_ARGS__);	\
 })
 
+#define cpuplugd_exit(fmt, ...) ({			\
+	cpuplugd_error(fmt, ##__VA_ARGS__);		\
+	clean_up();					\
+})
