@@ -454,6 +454,9 @@ static void dasdfmt_write_labels(dasdfmt_info_t *info, volume_label_t *vlabel,
 	format5_label_t     f5;
 	format7_label_t     f7;
 	int rc, blksize;
+	void *ipl1_record, *ipl2_record;
+	int ipl1_record_len, ipl2_record_len;
+
 
 	if (info->verbosity > 0) printf("Retrieving dasd information... ");
 
@@ -476,15 +479,32 @@ static void dasdfmt_write_labels(dasdfmt_info_t *info, volume_label_t *vlabel,
 
 	if (info->verbosity > 0) printf("ok\n");
 
-	/* write bootstrap */
+	/* write empty bootstrap (initial IPL records) */
 	if (info->verbosity > 0) printf("Writing empty bootstrap...\n");
 
+	/*
+	 * Note: ldl labels do not contain the key field
+	 */
+	if (info->cdl_format) {
+		/* Prepare copy with key (CDL) */
+		ipl1_record	= &ipl1;
+		ipl2_record	= &ipl2;
+		ipl1_record_len	= sizeof(ipl1);
+		ipl2_record_len	= sizeof(ipl2);
+	} else {
+		/* Prepare copy without key (LDL) */
+		ipl1_record	= ipl1.data;
+		ipl2_record	= ipl2.data;
+		ipl1_record_len	= sizeof(ipl1.data);
+		ipl2_record_len	= sizeof(ipl2.data);
+	}
+
 	if (lseek(filedes, 0, SEEK_SET) != 0)
 		ERRMSG_EXIT(EXIT_FAILURE, "%s: lseek command 0 failed "
 			    "(%s)\n", prog_name, strerror(errno));
 
-	rc = write(filedes, &ipl1, sizeof(bootstrap1_t));
-	if (rc != sizeof(bootstrap1_t))
+	rc = write(filedes, ipl1_record, ipl1_record_len);
+	if (rc != ipl1_record_len)
 		ERRMSG_EXIT(EXIT_FAILURE, "%s: Writing the bootstrap IPL1 "
 			    "failed, only wrote %d bytes.\n", prog_name, rc);
 
@@ -495,8 +515,8 @@ static void dasdfmt_write_labels(dasdfmt_info_t *info, volume_label_t *vlabel,
 			    "(%s).\n", prog_name, label_position, 
 			    strerror(errno));
 
-	rc = write(filedes, &ipl2, sizeof(bootstrap2_t));
-	if (rc != sizeof(bootstrap2_t))
+	rc = write(filedes, ipl2_record, ipl2_record_len);
+	if (rc != ipl2_record_len)
 		ERRMSG_EXIT(EXIT_FAILURE, "%s: Writing the bootstrap IPL2 "
 			    "failed, only wrote %d bytes.\n", prog_name, rc);
 
