@@ -239,7 +239,7 @@ static int find_busid_in_proc(int maja, int mina, char *busid)
 	while (fscanf(filp, "%[^(] %*s at ( %d : %d %*[^\n]\n",
 		      bus, &majb, &minb) != EOF) {
 		if ((maja == majb) && (mina == minb)) {
-			strncpy(busid, bus, BUSIDSIZE);
+			strncpy(busid, bus, BUSIDSIZE + 1);
 			rc = 0;
 			break;
 		}
