@@ -146,30 +146,25 @@ static char buffer[85];
  */
 static void vtoc_error(enum failure why, char *s1, char *s2) 
 {
-        char    error[LINE_LENGTH];
-
 	switch (why) {
 	case unable_to_open:
-	        sprintf(error, "%s opening device '%s' failed.\n%s\n",
+	        fprintf(stderr, "\n%s opening device '%s' failed.\n%s\n",
 			VTOC_ERROR, s1, s2);
 		break;
 	case unable_to_seek:
-	        sprintf(error, "%s seeking device '%s' failed.\n%s\n",
+	        fprintf(stderr, "\n%s seeking device '%s' failed.\n%s\n",
 			VTOC_ERROR, s1, s2);
 		break;
 	case unable_to_write:
-	        sprintf(error, "%s writing to device '%s' failed,\n%s\n",
+	        fprintf(stderr, "\n%s writing to device '%s' failed,\n%s\n",
 			VTOC_ERROR, s1, s2);
 		break;
 	case unable_to_read:
-	        sprintf(error, "%s reading from device '%s' failed.\n%s\n",
+	        fprintf(stderr, "\n%s reading from device '%s' failed.\n%s\n",
 			VTOC_ERROR, s1, s2);
 		break;
-	default: sprintf(error, "Fatal error\n");
+	default: fprintf(stderr, "\nFatal error\n");
 	}
-
-	fputc('\n', stderr);
-	fputs(error, stderr);
 	exit(1);
 }
 
@@ -326,7 +321,7 @@ void vtoc_volume_label_init (volume_label_t *vlabel)
 {
 	sprintf(buffer, "%84s", " ");
 	vtoc_ebcdic_enc(buffer, buffer, 84);	
-	strncpy(vlabel->volkey, buffer, 84);
+	memcpy(vlabel, buffer, 84);
 }
 
 
@@ -1204,7 +1199,7 @@ void vtoc_update_format7_label_add (format7_label_t *f7, int verbose,
 		if ((ext->a + ext->b) == 0x00000000)
 			continue;
 
-		if ((ext->b + 1) == tmp->a) {
+		if ((ext->b) == tmp->a) {
 			/* this extent precedes the new one */
 			ext->b = tmp->b;
 			bzero(tmp, sizeof(ds7ext_t));
@@ -1216,7 +1211,7 @@ void vtoc_update_format7_label_add (format7_label_t *f7, int verbose,
 			continue;
 		} 
 
-		if (ext->a == (tmp->b + 1))
+		if (ext->a == (tmp->b))
 		{
 			/* this extent succeeds the new one */
 			ext->a = tmp->a;
@@ -1240,7 +1235,7 @@ void vtoc_update_format7_label_del (format7_label_t *f7, int verbose,
 {
 	ds7ext_t *ext;
 	int i, counter=0;
-	
+
 	for (i=0; i<16; i++) {
 		if (i<5) 
 			ext = &f7->DS7EXTNT[i]; 
@@ -1258,7 +1253,7 @@ void vtoc_update_format7_label_del (format7_label_t *f7, int verbose,
 
 		if ((a == ext->a) && (b < ext->b)) {
 			/* left-bounded in free space gap */
-			ext->a = b + 1;
+			ext->a = b;
 			if (verbose) 
 				printf("FMT7 add extent: left-bounded\n");
 			counter++;
@@ -1267,7 +1262,7 @@ void vtoc_update_format7_label_del (format7_label_t *f7, int verbose,
 
 		if ((a > ext->a) && (b == ext->b)) {
 			/* right-bounded in free space gap */
-			ext->b = a - 1;
+			ext->b = a;
 			if (verbose) 
 				printf("FMT7 add extent: right-bounded\n");
 			counter++;
@@ -1277,8 +1272,8 @@ void vtoc_update_format7_label_del (format7_label_t *f7, int verbose,
 		if ((a > ext->a) && (b < ext->b)) {
 			/* partition devides free space into 2 pieces */
 			vtoc_update_format7_label_add(f7, verbose, 
-						      b+1, ext->b);
-			ext->b = a - 1;
+						      b, ext->b);
+			ext->b = a;
 			if (verbose) 
 				printf("FMT7 add extent: 2 pieces\n");
 			counter++;
@@ -1311,10 +1306,14 @@ void vtoc_set_freespace(format4_label_t *f4, format5_label_t *f5,
 {
 	if ((cyl * trk) > BIG_DISK_SIZE) {
 		if (ch == '+') {
-			vtoc_update_format7_label_add(f7, verbose, start,stop);
+			vtoc_update_format7_label_add(f7, verbose, start,
+						      /* ds7ext RTA + 1 */
+						      stop + 1);
 		}
 		else if (ch == '-') {
-			vtoc_update_format7_label_del(f7, verbose, start,stop);
+			vtoc_update_format7_label_del(f7, verbose, start,
+						      /* ds7ext RTA + 1 */
+						      stop + 1);
 		}
 		else {
 			printf("BUG: syntax error in vtoc_set_freespace.\n");
