@@ -18,7 +18,7 @@
 #include "ziorep_utils.hpp"
 
 #define	ZIOREP_CFG_EXTENSION	".cfg"
-#define ZIOREP_CONFIG_PATH	"/sbin/ziorep_config"
+#define ZIOREP_CONFIG		"ziorep_config"
 
 extern const char *toolname;
 extern int verbose;
@@ -158,18 +158,6 @@ int ConfigReader::filter_unused_devices(const char *filename)
 }
 
 
-int ConfigReader::check_ziorep_config() const
-{
-	if (access(ZIOREP_CONFIG_PATH, F_OK | R_OK | X_OK)) {
-		fprintf(stderr, "%s: Cannot access " ZIOREP_CONFIG_PATH
-			". Please check your installation and try again.\n", toolname);
-		return -1;
-	}
-
-	return 0;
-}
-
-
 int ConfigReader::check_config_file(const char *fname) const
 {
 	char *tmp;
@@ -204,8 +192,6 @@ int ConfigReader::extract_config_data(const char *fname)
 
 	// Try to extract to .config first, which will be permanently cached
 	verbose_msg("No data cached, extract\n");
-	if (check_ziorep_config())
-		return -1;
 
 	fprintf(stdout, "Extracting config data...");
 	fflush(stdout);
@@ -215,8 +201,8 @@ int ConfigReader::extract_config_data(const char *fname)
 		if (extract_tmp(fname)) {
 			fprintf(stderr, "%s: Could not extract"
 				" configuration data. Check the integrity of"
-				" %s%s with %s and retry.", toolname, fname,
-				ZIOREP_CFG_EXTENSION, ZIOREP_CONFIG_PATH);
+				" %s%s with %s and retry.\n", toolname, fname,
+				ZIOREP_CFG_EXTENSION, ZIOREP_CONFIG);
 			return -1;
 		}
 	}
@@ -286,11 +272,11 @@ int ConfigReader::extract(const char *fname)
 	char *cmd = NULL;
 
 	// /sbin/ziorep_config -I -i <fname.cfg> > <file> 2>/dev/null
-	cmd = (char*)malloc(strlen(ZIOREP_CONFIG_PATH) + 7 + strlen(fname)
+	cmd = (char*)malloc(strlen(ZIOREP_CONFIG) + 7 + strlen(fname)
 		     + strlen(ZIOREP_CFG_EXTENSION) + 3 + strlen(m_tmp_file)
 		     + 12 + 1);
 
-	sprintf(cmd, "%s -I -i %s%s > %s 2>/dev/null", ZIOREP_CONFIG_PATH, fname,
+	sprintf(cmd, "%s -I -i %s%s > %s 2>/dev/null", ZIOREP_CONFIG, fname,
 		ZIOREP_CFG_EXTENSION, m_tmp_file);
 
 	verbose_msg("Issue command: %s\n", cmd);
@@ -669,7 +655,8 @@ const struct hctl_ident* ConfigReader::get_ident_by_mm_internal(__u32 mm, int *r
 	for (list<struct device_info>::const_iterator i = m_devices.begin(); \
 	      i != m_devices.end(); ++i) { \
 		list<type>::iterator j; \
-		for (j = tgt.begin(); j != tgt.end() && (*i).a != (*j); ++j); \
+		for (j = tgt.begin(); j != tgt.end() && (*i).a != (*j); ++j) \
+			; \
 		if (j == tgt.end()) \
 			tgt.push_back((*i).a); \
 	}
