@@ -156,7 +156,11 @@ void Printer::print_abbreviated(FILE *fp, double num, int leading_places,
 
 	rc = fprintf(fp, "%*.*lf%c", max_digs - 1, num_places, num / factor, magnitude);
 
+#ifdef NDEBUG
+	(void)(rc);
+#else
 	assert(rc <= max_digs);
+#endif
 }
 
 
