@@ -18,16 +18,14 @@
 #define ZIPL_MAGIC_SIZE			4
 #define DISK_LAYOUT_ID			0x00000001
 
-#define ZIPL_STAGE2_LOAD_ADDRESS	0x2000
+#define ZIPL_STAGE2_LOAD_ADDRESS        0x2000
 #define ZIPL_STAGE3_ENTRY_ADDRESS	0xa028LL
-#define DEFAULT_PARMFILE_ADDRESS	0x1000LL
-#define DEFAULT_STAGE3_ADDRESS		0xa000LL
 #define DEFAULT_IMAGE_ADDRESS		0x10000LL
+#define DEFAULT_STAGE3_ADDRESS          0xa000LL
 #define MINIMUM_ADDRESS 		0x10000LL
 #define ADDRESS_LIMIT 			0x80000000LL
 #define UNSPECIFIED_ADDRESS		-1ULL
 #define MAXIMUM_PARMLINE_SIZE 		0x380
-#define MAXIMUM_STAGE3_SIZE 		0x1000
 #define MAXIMUM_PHYSICAL_BLOCKSIZE 	0x1000
 
 #define PSW_ADDRESS_MASK		0x000000007fffffffLL
