@@ -120,7 +120,7 @@ disk_get_info(const char* device, struct job_target_data* target,
 		return -1;
 	}
 	/* Open device file */
-	fd = open(device, O_RDWR);
+	fd = open(device, O_RDONLY);
 	if (fd == -1) {
 		error_reason(strerror(errno));
 		return -1;
