@@ -332,7 +332,12 @@ install_bootloader(const char* device, disk_blockptr_t *program_table,
 		/* Should not happen */
 		break;
 	}
-	close(fd);
+
+	if (fsync(fd))
+		error_text("Could not sync device file '%s'", device);
+	if (close(fd))
+		error_text("Could not close device file '%s'", device);
+
 	if (!dry_run && rc == 0) {
 		if (info->devno >= 0)
 			syslog(LOG_INFO, "Boot loader written to %s (%04x) - "
@@ -1066,7 +1071,10 @@ install_dump(const char* device, struct job_target_data* target, uint64_t mem)
 	}
 	misc_free_temp_dev(tempdev);
 	disk_free_info(info);
-	close(fd);
+	if (fsync(fd))
+		error_text("Could not sync device file '%s'", device);
+	if (close(fd))
+		error_text("Could not close device file '%s'", device);
 	return rc;
 }
 
@@ -1195,7 +1203,12 @@ install_mvdump(char* const device[], struct job_target_data* target, int count,
 		rc = install_mvdump_eckd_compatible(fd, info[i], mem, force,
 						    parm);
 		misc_free_temp_dev(tempdev);
-		close(fd);
+
+		if (fsync(fd))
+			error_text("Could not sync device file '%s'", device);
+		if (close(fd))
+			error_text("Could not close device file '%s'", device);
+
 		if (rc)
 			goto out;
 	}
