@@ -24,7 +24,6 @@
 #include "misc.h"
 #include "scan.h"
 
-
 /* Command line options */
 static struct option options[] = {
 	{ "config",		required_argument,	NULL, 'c'},
@@ -494,14 +493,14 @@ sort_cl_array(struct component_loc* cl, int elements)
 
 static int
 get_ipl_components(struct job_ipl_data *ipl, struct component_loc **clp,
-		   int *nump, address_t *stage3_addrp)
+		   int *nump)
 {
 	struct component_loc *cl;
 	int num;
 	int rc;
 
-	/* Get memory for image, parmline, ramdisk, loader */
-	cl = misc_calloc(4, sizeof(struct component_loc));
+	/* Get memory for image, parmline, ramdisk */
+	cl = misc_calloc(3, sizeof(struct component_loc));
 	if (cl == NULL)
 		return -1;
 	/* Fill in component data */
@@ -524,10 +523,7 @@ get_ipl_components(struct job_ipl_data *ipl, struct component_loc **clp,
 		if (rc)
 			goto error;
 	}
-	rc = set_cl_element(&cl[num++], "internal loader", NULL, stage3_addrp,
-		MAXIMUM_STAGE3_SIZE, 0, MAXIMUM_PHYSICAL_BLOCKSIZE);
-	if (rc)
-		goto error;
+
 	*clp = cl;
 	*nump = num;
 	return 0;
@@ -539,15 +535,14 @@ error:
 
 static int
 get_dump_fs_components(struct job_dump_fs_data *dump_fs,
-		       struct component_loc **clp, int *nump,
-		       address_t *stage3_addrp)
+		       struct component_loc **clp, int *nump)
 {
 	struct component_loc *cl;
 	int num;
 	int rc;
 
 	/* Get memory for image, parmline, ramdisk, loader */
-	cl = misc_calloc(4, sizeof(struct component_loc));
+	cl = misc_calloc(3, sizeof(struct component_loc));
 	if (cl == NULL)
 		return -1;
 	/* Fill in component data */
@@ -569,10 +564,7 @@ get_dump_fs_components(struct job_dump_fs_data *dump_fs,
 		if (rc)
 			goto error;
 	}
-	rc = set_cl_element(&cl[num++], "internal loader", NULL, stage3_addrp,
-			    MAXIMUM_STAGE3_SIZE, 0, MAXIMUM_PHYSICAL_BLOCKSIZE);
-	if (rc)
-		goto error;
+
 	*clp = cl;
 	*nump = num;
 	return 0;
@@ -643,6 +635,14 @@ check_component_address_data(struct component_loc *cl, int num, char *name)
 				     ADDRESS_LIMIT);
 			return -1;
 		}
+		if (*cl[i].addrp < MINIMUM_ADDRESS) {
+			if (name != NULL)
+				error_text("Section '%s'", name);
+			error_reason("Component '%s' falls below available "
+				     "address space (limit is 0x%08x)",
+				     cl[i].name, MINIMUM_ADDRESS);
+			return -1;
+		}
 	}
 	/* Check for overlap */
 	for (i = 0; i < num - 1; i++) {
@@ -717,10 +717,9 @@ finalize_ipl_address_data(struct job_ipl_data* ipl, char *name)
 {
 	struct component_loc *cl;
 	int num;
-	address_t stage3_addr = DEFAULT_STAGE3_ADDRESS;
 	int rc;
 
-	rc = get_ipl_components(ipl, &cl, &num, &stage3_addr);
+	rc = get_ipl_components(ipl, &cl, &num);
 	if (rc)
 		return rc;
 	sort_cl_array(cl, num);
@@ -739,10 +738,9 @@ finalize_dump_fs_address_data(struct job_dump_fs_data* dump_fs, char *name)
 {
 	struct component_loc *cl;
 	int num;
-	address_t stage3_addr = DEFAULT_STAGE3_ADDRESS;
 	int rc;
 
-	rc = get_dump_fs_components(dump_fs, &cl, &num, &stage3_addr);
+	rc = get_dump_fs_components(dump_fs, &cl, &num);
 	if (rc)
 		return rc;
 	sort_cl_array(cl, num);
@@ -904,7 +902,7 @@ check_job_dump_fs_data(struct job_dump_fs_data* dump_fs, char* name)
 		dump_fs->ramdisk_addr = UNSPECIFIED_ADDRESS;
 	}
 
-	dump_fs->parm_addr = DEFAULT_PARMFILE_ADDRESS;
+	dump_fs->parm_addr = UNSPECIFIED_ADDRESS;
 	return finalize_dump_fs_address_data(dump_fs, name);
 }
 
@@ -1195,7 +1193,7 @@ get_parmline(char* filename, char* line, char** parmline, address_t* address,
 	int to;
 	int got_lf;
 
-	addr = DEFAULT_PARMFILE_ADDRESS;
+	addr = UNSPECIFIED_ADDRESS;
 	if (filename != NULL) {
 		/* Need a filename copy to be able to change it */
 		filename = misc_strdup(filename);
